==> divine-2.0.tar.gz: divine-2.0/gui/ltl_editor/ltl_editor_plugin.cpp <==
/***************************************************************************
 *   Copyright (C) 2009 by Martin Moracek                                  *
 *   xmoracek@fi.muni.cz                                                   *
 *                                                                         *
 *   DiVinE is free software, distributed under GNU GPL and BSD licences.  *
 *   Detailed licence texts may be found in the COPYING file in the        *
 *   distribution tarball. The tool is a product of the ParaDiSe           *
 *   Laboratory, Faculty of Informatics of Masaryk University.             *
 *                                                                         *
 *   This distribution includes freely redistributable third-party code.   *
 *   Please refer to AUTHORS and COPYING included in the distribution for  *
 *   copyright and licensing details.                                      *
 ***************************************************************************/

#include <QtPlugin>
#include <QUrl>

#include "ltl_editor_plugin.h"
#include "ltl_highlighter.h"
#include "prefs_ltl.h"
#include "mainform.h"
#include "editor.h"

LtlBuilder::LtlBuilder(MainForm * root) : EditorBuilder(root), root_(root)
{
}

void LtlBuilder::install(SourceEditor * editor)
{
  QUrl url(editor->document()->metaInformation(QTextDocument::DocumentUrl));
  
  LtlHighlighter * highlight = new LtlHighlighter(url.scheme() == "mltl", editor->document());
  highlight->setObjectName("ltlHighlighter");
  
  connect(root_, SIGNAL(settingsChanged()), highlight, SLOT(readSettings()));
  
  QStringList wordList;
  wordList << "accept" << "and" << "assert" << "async" << "byte" << "channel"
           << "commit" << "const" << "effect" << "false" << "guard" << "int"
           << "imply" << "init" << "or" << "process" << "property" << "state"
           << "sync" << "system" << "trans" << "true";
}

void LtlBuilder::uninstall(SourceEditor * editor)
{
  LtlHighlighter * highlight = editor->document()->findChild<LtlHighlighter*>("ltlHighlighter");
  Q_ASSERT(highlight);
  delete highlight;
}

void LtlEditorPlugin::install(MainForm * root)
{
  // document loaders
  EditorBuilder * loader = new LtlBuilder(root);
  root->registerDocument("ltl", tr("LTL files (*.ltl)"), loader);
  root->registerDocument("mltl", tr("MLTL files (*.mltl)"), loader);
  
  // preferences
  PreferencesPage * page = new LtlPreferences();
  root->registerPreferences(QObject::tr("Syntax"), QObject::tr("LTL"), page);
}

Q_EXPORT_PLUGIN2(ltl_editor, LtlEditorPlugin)

==> divine-2.1.tar.gz: divine-2.1/gui/ltl_editor/ltl_editor_plugin.cpp <==
/***************************************************************************
 *   Copyright (C) 2009 by Martin Moracek                                  *
 *   xmoracek@fi.muni.cz                                                   *
 *                                                                         *
 *   DiVinE is free software, distributed under GNU GPL and BSD licences.  *
 *   Detailed licence texts may be found in the COPYING file in the        *
 *   distribution tarball. The tool is a product of the ParaDiSe           *
 *   Laboratory, Faculty of Informatics of Masaryk University.             *
 *                                                                         *
 *   This distribution includes freely redistributable third-party code.   *
 *   Please refer to AUTHORS and COPYING included in the distribution for  *
 *   copyright and licensing details.                                      *
 ***************************************************************************/

#include <QtPlugin>
#include <QUrl>

#include "ltl_editor_plugin.h"
#include "ltl_highlighter.h"
#include "prefs_ltl.h"
#include "mainform.h"
#include "editor.h"

LtlEditorBuilder::LtlEditorBuilder(MainForm * root) : EditorBuilder(root), root_(root)
{
}

void LtlEditorBuilder::install(SourceEditor * editor)
{
  QUrl url(editor->document()->metaInformation(QTextDocument::DocumentUrl));
  
  LtlHighlighter * highlight = new LtlHighlighter(editor->document());
  highlight->setObjectName("ltlHighlighter");
  
  connect(root_, SIGNAL(settingsChanged()), highlight, SLOT(readSettings()));                                                                             
}

void LtlEditorBuilder::uninstall(SourceEditor * editor)
{
  LtlHighlighter * highlight = editor->document()->findChild<LtlHighlighter*>("ltlHighlighter");
  Q_ASSERT(highlight);
  delete highlight;
}

void LtlEditorPlugin::install(MainForm * root)
{
  // document loaders
  EditorBuilder * loader = new LtlEditorBuilder(root);
  root->registerDocument("ltl", tr("LTL files (*.ltl)"), loader);
  
  // preferences
  PreferencesPage * page = new LtlPreferences();
  root->registerPreferences(QObject::tr("Syntax"), QObject::tr("LTL"), page);
}

Q_EXPORT_PLUGIN2(ltl_editor, LtlEditorPlugin)
